==> cxf-testutils-2.3.1-fuse-01-00-sources.jar: org/apache/type_test/types3/ChoiceWithSubstitutionGroupAbstract.java <==

package org.apache.type_test.types3;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ChoiceWithSubstitutionGroupAbstract complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ChoiceWithSubstitutionGroupAbstract">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice>
 *         &lt;element ref="{http://apache.org/type_test/types3}sg03AbstractBaseElement_A"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}unsignedLong"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ChoiceWithSubstitutionGroupAbstract", propOrder = {
    "sg03AbstractBaseElementA",
    "varInt"
})
public class ChoiceWithSubstitutionGroupAbstract {

    @XmlElementRef(name = "sg03AbstractBaseElement_A", namespace = "http://apache.org/type_test/types3", type = JAXBElement.class, required = false)
    protected JAXBElement<? extends SgBaseTypeA> sg03AbstractBaseElementA;
    @XmlSchemaType(name = "unsignedLong")
    protected BigInteger varInt;

    /**
     * Gets the value of the sg03AbstractBaseElementA property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     
     */
    public JAXBElement<? extends SgBaseTypeA> getSg03AbstractBaseElementA() {
        return sg03AbstractBaseElementA;
    }

    /**
     * Sets the value of the sg03AbstractBaseElementA property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     
     */
    public void setSg03AbstractBaseElementA(JAXBElement<? extends SgBaseTypeA> value) {
        this.sg03AbstractBaseElementA = ((JAXBElement<? extends SgBaseTypeA> ) value);
    }

    /**
     * Gets the value of the varInt property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setVarInt(BigInteger value) {
        this.varInt = value;
    }

}

==> cxf-testutils-2.3.5-fuse-01-33-sources.jar: org/apache/type_test/types3/ChoiceWithSubstitutionGroupAbstract.java <==

package org.apache.type_test.types3;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ChoiceWithSubstitutionGroupAbstract complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ChoiceWithSubstitutionGroupAbstract">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice>
 *         &lt;element ref="{http://apache.org/type_test/types3}sg03AbstractBaseElement_A"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}unsignedLong"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ChoiceWithSubstitutionGroupAbstract", propOrder = {
    "sg03AbstractBaseElementA",
    "varInt"
})
public class ChoiceWithSubstitutionGroupAbstract {

    @XmlElementRef(name = "sg03AbstractBaseElement_A", namespace = "http://apache.org/type_test/types3", type = JAXBElement.class)
    protected JAXBElement<? extends SgBaseTypeA> sg03AbstractBaseElementA;
    @XmlSchemaType(name = "unsignedLong")
    protected BigInteger varInt;

    /**
     * Gets the value of the sg03AbstractBaseElementA property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     
     */
    public JAXBElement<? extends SgBaseTypeA> getSg03AbstractBaseElementA() {
        return sg03AbstractBaseElementA;
    }

    /**
     * Sets the value of the sg03AbstractBaseElementA property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     
     */
    public void setSg03AbstractBaseElementA(JAXBElement<? extends SgBaseTypeA> value) {
        this.sg03AbstractBaseElementA = ((JAXBElement<? extends SgBaseTypeA> ) value);
    }

    /**
     * Gets the value of the varInt property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setVarInt(BigInteger value) {
        this.varInt = value;
    }

}
